==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/dialogs/fixpunctuationdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "fixpunctuationdialog.h"

#include <qgroupbox.h>
#include <qcheckbox.h>
#include <qlayout.h>

#include <klocale.h>


using namespace SubtitleComposer;

FixPunctuationDialog::FixPunctuationDialog( QWidget* parent ):
	TargetableTextsActionDialog( i18n( "Fix Punctuation" ), parent )
{
	QGroupBox* caseGroupBox = createGroupBox( i18n( "Settings" ) );

	m_spacesCheckBox = new QCheckBox( caseGroupBox );
	m_spacesCheckBox->setText( i18n( "Fix and cleanup spaces" ) );
	m_spacesCheckBox->setChecked( true );

	m_quotesCheckBox = new QCheckBox( caseGroupBox );
	m_quotesCheckBox->setText( i18n( "Fix quotes and double quotes" ) );
	m_quotesCheckBox->setChecked( true );

	m_englishICheckBox = new QCheckBox( caseGroupBox );
	m_englishICheckBox->setText( i18n( "Fix English 'I' pronoun" ) );
	m_englishICheckBox->setChecked( true );

	m_ellipsisCheckBox = new QCheckBox( caseGroupBox );
	m_ellipsisCheckBox->setText( i18n( "Add ellipisis indicating non finished lines" ) );
	m_ellipsisCheckBox->setChecked( true );

	createTextsTargetGroupBox();
	createLinesTargetGroupBox();

	QGridLayout* caseLayout = createLayout( caseGroupBox );
	caseLayout->addWidget( m_spacesCheckBox, 0, 0 );
	caseLayout->addWidget( m_quotesCheckBox, 1, 0 );
	caseLayout->addWidget( m_englishICheckBox, 2, 0 );
	caseLayout->addWidget( m_ellipsisCheckBox, 3, 0 );
}

bool FixPunctuationDialog::spaces()
{
	return m_spacesCheckBox->isChecked();
}

bool FixPunctuationDialog::quotes()
{
	return m_quotesCheckBox->isChecked();
}

bool FixPunctuationDialog::englishI()
{
	return m_englishICheckBox->isChecked();
}

bool FixPunctuationDialog::ellipisis()
{
	return m_ellipsisCheckBox->isChecked();
}

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/main/dialogs/fixpunctuationdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "fixpunctuationdialog.h"

#include <qbuttongroup.h>
#include <qcheckbox.h>
#include <qlayout.h>

#include <klocale.h>


using namespace SubtitleComposer;

FixPunctuationDialog::FixPunctuationDialog( QWidget* parent ):
	ActionWithTargetDialog( i18n( "Fix Punctuation" ), parent )
{
	QButtonGroup* settingsButtonGroup = createButtonGroup( i18n( "Settings" ) );

	m_spacesCheckBox = new QCheckBox( settingsButtonGroup );
	m_spacesCheckBox->setText( i18n( "Fix and cleanup spaces" ) );
	m_spacesCheckBox->setChecked( true );

	m_quotesCheckBox = new QCheckBox( settingsButtonGroup );
	m_quotesCheckBox->setText( i18n( "Fix quotes and double quotes" ) );
	m_quotesCheckBox->setChecked( true );

	m_englishICheckBox = new QCheckBox( settingsButtonGroup );
	m_englishICheckBox->setText( i18n( "Fix English 'I' pronoun" ) );
	m_englishICheckBox->setChecked( true );

	m_ellipsisCheckBox = new QCheckBox( settingsButtonGroup );
	m_ellipsisCheckBox->setText( i18n( "Add ellipisis indicating non finished lines" ) );
	m_ellipsisCheckBox->setChecked( true );


	createLinesTargetButtons();
	createTextsTargetButtons();


	QGridLayout* settingsLayout = createLayout( settingsButtonGroup );
	settingsLayout->addWidget( m_spacesCheckBox, 0, 0 );
	settingsLayout->addWidget( m_quotesCheckBox, 1, 0 );
	settingsLayout->addWidget( m_englishICheckBox, 2, 0 );
	settingsLayout->addWidget( m_ellipsisCheckBox, 3, 0 );
}

bool FixPunctuationDialog::spaces() const
{
	return m_spacesCheckBox->isChecked();
}

bool FixPunctuationDialog::quotes() const
{
	return m_quotesCheckBox->isChecked();
}

bool FixPunctuationDialog::englishI() const
{
	return m_englishICheckBox->isChecked();
}

bool FixPunctuationDialog::ellipisis() const
{
	return m_ellipsisCheckBox->isChecked();
}
